@@ -48,7 +48,8 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
         isResumePlayback(false),
         isMainToolbarVisible(false),
         isSeekSliderShown(true),
-        fileListWidgetItemFileToDelete(QString())
+        fileListWidgetItemIndexToDelete(-1),
+        forceUpdatePlayList(false)
 {
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->setupUi(this);
@@ -135,6 +136,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     connect(this->ui->menuActionEqualizer, SIGNAL(triggered()), this, SLOT(showEqualizerWindowSlot()));
 
+    connect(this->ui->menuActionSupportSymfonie, SIGNAL(triggered()), this, SLOT(supportSymfonieSlot()));
 
 
     connect(this->ui->menuActionAbout, SIGNAL(triggered()), this, SLOT(showAboutWindowSlot()));
@@ -272,11 +274,11 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     
     // this->player->scanDir(this->getCurrentDiretory(), true);
 
-
+/*
     this->ui->fileListWidget->setContextMenuPolicy(Qt::CustomContextMenu);
 
-    // connect(this->ui->fileListWidget, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(fileListItemContextMenu(const QPoint &)));
-
+    connect(this->ui->fileListWidget, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(fileListItemContextMenu(const QPoint &)));
+*/
 
 
 
@@ -322,11 +324,18 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 }
 
 void MainWindow::deleteFileSlot(){
-    qDebug() << "Trying to delete file: " <<this->fileListWidgetItemFileToDelete;
+    if(this->fileListWidgetItemIndexToDelete < 0){
+        qDebug() << "Nothing selected. this->fileListWidgetItemIndexToDelete" << this->fileListWidgetItemIndexToDelete;
+        return;
+    }
+    QString filePath = this->currentPlayList
+                       ->get(this->fileListWidgetItemIndexToDelete)
+                       ->getName();
+    qDebug() << "Trying to delete file: " << filePath;
 
     QMessageBox msgBox;
     // msgBox.setText(tr("File Deletion"));
-     msgBox.setInformativeText(tr("Are you sure you want to delete this file?\n") + this->fileListWidgetItemFileToDelete);
+     msgBox.setInformativeText(tr("Are you sure you want to delete this file?\n") + filePath);
      msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
      msgBox.setDefaultButton(QMessageBox::No);
      int ret = msgBox.exec();
@@ -337,19 +346,30 @@ void MainWindow::deleteFileSlot(){
      }
 
 
-    QFileInfo info = QFileInfo(this->fileListWidgetItemFileToDelete);
+    QFileInfo info = QFileInfo(filePath);
     if(!info.exists() || !info.isFile()){
         qDebug() << "deleteFileSlot: not a filed, operation skipped.";
         return;
     }
 
-  //  this->getPlayer()->getMediaObject()->stop();
+    if(
+            QString::compare(this->getCurrentDiretory(), this->getPlayer()->getCurrentDirectory()) == 0 &&
+            this->fileListWidgetItemIndexToDelete == this->getPlayer()->getCurrentPlaybackIndex()){
+        this->getPlayer()->stop();
+        this->forceUpdatePlayList = true;
+    }
 
-    if(!QFile::remove(this->fileListWidgetItemFileToDelete)){
-        qDebug() << "deleteFileSlot: deletion failed: "<< this->fileListWidgetItemFileToDelete;
+
+
+    if(!QFile::remove(filePath)){
+        qDebug() << "deleteFileSlot: deletion failed: "<< filePath;
+        QMessageBox msgBox;
+        msgBox.setInformativeText(tr("Unable to delete selected file."));
+        msgBox.exec();
         return;
     }
 
+
     this->getPlayer()->scanDir(this->getCurrentDiretory());
 
 
@@ -364,18 +384,24 @@ void MainWindow::fileListItemContextMenu(const QPoint &pos){
         return;
     }
 
-    itemIndex = item->data(Qt::UserRole).toInt();
+      itemIndex = item->data(Qt::UserRole).toInt();
+
+    if(this->currentPlayList->get(itemIndex)->getItemType() != SymfoniePlayListItemFile::File){
+        return;
+    }
+
+
 
     SymfonieQMenu *menu = new SymfonieQMenu();
 
 
-    if(this->getPlayer()->getPlayList()->get(itemIndex)->getItemType() == SymfoniePlayListItemFile::File){
-        this->fileListWidgetItemFileToDelete = this->getPlayer()->getPlayList()->get(itemIndex)->getName();
-        menu->addAction(tr("Delete File"), this, SLOT(deleteFileSlot()));
-    }
+
+    this->fileListWidgetItemIndexToDelete = itemIndex;
+    menu->addAction(tr("Delete File"), this, SLOT(deleteFileSlot()));
+
     menu->exec(this->mapToGlobal(pos));
-   // delete menu;
-    this->fileListWidgetItemFileToDelete = QString();
+    // delete menu;
+    this->fileListWidgetItemIndexToDelete = -1;
 
 
 }
@@ -538,6 +564,10 @@ void MainWindow::setOrientationMode(int mode){
 }
 
 
+void MainWindow::supportSymfonieSlot(){
+    QDesktopServices::openUrl(QUrl("http://thecodecentral.com/symfonie#dd", QUrl::TolerantMode));
+}
+
 void MainWindow::toggleFullScreenOn(){
     toggleFullScreen(true);
 }
@@ -699,7 +729,6 @@ void MainWindow::goUpSlot(){
 
     QDir homeDir = QDir(QDir::homePath() + "/MyDocs");
     QDir mediaDir = QDir("/media");
-    qDebug() << "sdflskjadf=-===========: "<< homeDir.canonicalPath() << this->getCurrentDiretory();
 
 
     if(this->getCurrentDiretory().length() == 0 ||
@@ -974,6 +1003,11 @@ void MainWindow::insertItem(SymfoniePlayList* playList){
 
         counter++;
     }
+
+    if(this->ui->fileListWidget->selectedItems().size() > 0){
+        this->ui->fileListWidget->scrollToItem(this->ui->fileListWidget->selectedItems().value(0), QAbstractItemView::EnsureVisible);
+    }
+
 }
 
 void MainWindow::changeEvent(QEvent *e)
@@ -991,6 +1025,8 @@ void MainWindow::changeEvent(QEvent *e)
 
 void MainWindow::itemActivatedSlot(QModelIndex index)
 {
+    this->ui->fileListWidget->setCurrentIndex(index);
+
     int row = index.row();
     SymfoniePlayList *playList = this->currentPlayList;
     SymfoniePlayListItem *item = playList->get(row);
@@ -1055,6 +1091,8 @@ void MainWindow::playNextSlot(){
 
 }
 
+
+
 void MainWindow::playPrevSlot(){
     qDebug() << "prev";
     this->player->playPrevious();
@@ -1128,8 +1166,11 @@ void MainWindow::playerScanDirCompletedSlot(SymfoniePlayList* playList, QString
     this->setCurrentDirectory(playList->getCurrentDirectory());
     this->insertItem(playList);
 
-
-
+    if(this->forceUpdatePlayList){
+        this->getPlayer()->stop();
+        this->getPlayer()->setPlayList(playList);
+        this->forceUpdatePlayList = false;
+    }
 
 
     if(this->isResumePlayback == true){
