@@ -1,4 +1,4 @@
 /usr/bin/qmake symfonie.pro
 #make clean
-make
+make -j 4
 run-standalone.sh ./symfonie
