@@ -21,7 +21,7 @@ SymfonieAboutDialog::~SymfonieAboutDialog()
 }
 
 void SymfonieAboutDialog::openHomeUrlSlot(){
-     QDesktopServices::openUrl(QUrl("http://thecodecentral.com", QUrl::TolerantMode));
+     QDesktopServices::openUrl(QUrl("http://thecodecentral.com/symfonie", QUrl::TolerantMode));
 }
 
 void SymfonieAboutDialog::changeEvent(QEvent *e)
