@@ -13,6 +13,10 @@ public:
     SymfonieAboutDialog(QWidget *parent = 0);
     ~SymfonieAboutDialog();
 
+
+public Q_SLOTS:
+    void openHomeUrlSlot();
+
 protected:
     void changeEvent(QEvent *e);
 
