@@ -102,7 +102,7 @@ bool SymfonieFullScreenExitButton::eventFilter(QObject *obj, QEvent *ev)
     if (obj != parent())
         return QToolButton::eventFilter(obj, ev);
 
-    int btnX, btnY, sliderX, sliderY;
+    int btnX, btnY;
     MainWindow *parent = (MainWindow*)parentWidget();
     bool isFullScreen = parent->windowState() & Qt::WindowFullScreen;
 
