@@ -567,6 +567,10 @@ void SymfonieMediaPlayer::enqueue(int index){
     this->queuedIndex = index;
 }
 
+void SymfonieMediaPlayer::stop(){
+    this->player->stop();
+}
+
 void SymfonieMediaPlayer::playPrevious(){
     this->enqueue(this->getPreviousPlaybackIndex());
     this->play();
@@ -595,20 +599,22 @@ void SymfonieMediaPlayer::setIsContinuouslyPlay(bool flag){
 }
 
 bool SymfonieMediaPlayer::getIsContinuouslyPlay(){
-    this->isContinuouslyPlay;
+    return this->isContinuouslyPlay;
 }
 
 void SymfonieMediaPlayer::aboutToFinishSlot(){
-    if(this->getIsContinuouslyPlay() && this->getPlayList()->isIndexLast(this->getCurrentPlaybackIndex())){
-        return;
-    }
-
+    if(!this->getIsContinuouslyPlay() && this->getPlayList()->isIndexLast(this->getCurrentPlaybackIndex())){
+        this->player->stop();
+    }else{
     this->queuedIndex = this->getNextPlaybackIndex();
 
-
     this->player->clearQueue();
     this->player->enqueue(Phonon::MediaSource(this->getFilePathAt(this->queuedIndex)));
 }
+    qDebug() << "IS con:" << this->getIsContinuouslyPlay()
+            << "Is last: "<< this->getPlayList()->isIndexLast(this->getCurrentPlaybackIndex())
+            << "current index: " << this->getCurrentPlaybackIndex();
+}
 
 
 void SymfonieMediaPlayer::currentSourceChangedSlot ( const Phonon::MediaSource &/*newSource*/ ) {
