@@ -22,6 +22,15 @@ SymfonieOptionsDialog::SymfonieOptionsDialog(MainWindow *parent) :
         this->ui->isAutoResumePlayback->setChecked(false);
     }
 
+    if(SymfonieDb::getInstance()->getSetting("is_continuously_play", 1).toInt() == 1){
+        this->ui->isContinuouslyPlay->setChecked(true);
+    }else{
+        this->ui->isContinuouslyPlay->setChecked(false);
+    }
+
+    this->ui->playListFontSizeSb->setValue(SymfonieDb::getInstance()->getSetting("playlist_font_size", 14).toInt());
+
+
 }
 
 SymfonieOptionsDialog::~SymfonieOptionsDialog()
@@ -49,3 +58,12 @@ bool SymfonieOptionsDialog::getOptionIsShowToolbar(){
 bool SymfonieOptionsDialog::getOptionIsAutoResumePlayback(){
     return this->ui->isAutoResumePlayback->isChecked();
 }
+
+bool SymfonieOptionsDialog::getIsContinuouslyPlay(){
+    return this->ui->isContinuouslyPlay->isChecked();
+}
+
+
+int SymfonieOptionsDialog::getPlayListFontSizeSbValue(){
+    return this->ui->playListFontSizeSb->value();
+}
