@@ -15,7 +15,7 @@ signals:
 public slots:
 
 protected:
-    void paintEvent(QPaintEvent *event);
+   // void paintEvent(QPaintEvent *event);
 
 
 
